@@ -38,7 +38,7 @@ _defaults = {
     'profile_files'     : ('project.apache.conf', 'trac-defaults.ini', 'permissions.ini')
 }
 
-_version = '0.4.3'
+_version = '0.4.4'
 
 class CleverboxAdmin(cmd.Cmd):
     intro = ''
@@ -68,7 +68,7 @@ class CleverboxAdmin(cmd.Cmd):
     def env_set(self, envname, env=None):
         self.envname = envname
         self.prompt = "Cleverbox [%s] > " % self.envname
-        
+
         # Check if environment needs an upgrade
         #  - open VERSION
         try:
@@ -78,21 +78,21 @@ class CleverboxAdmin(cmd.Cmd):
                 print "A bug in trac-0.10.3 prevents the cleverbox from working correctly."
                 print "Please upgrade or downgrade your trac installation."
                 print
-                
+
                 sys.exit(1)
-            
+
             env_version = open(os.path.join(self.envname, 'VERSION')).read().strip()
-            
+
             #  - compare with self._version
             #  - if VERSION < self._version :
-            if parse_version(env_version) < parse_version(_version): 
+            if parse_version(env_version) < parse_version(_version):
                 print "\nCleverbox environment needs to be upgraded. Please run :"
                 print "  cleverbox-admin %s upgrade\n" % self.envname
                 sys.exit(1)
         except IOError, e:
             # no VERSION file means user wants to create an environment
             pass
-        
+
         if env is not None:
             self.__env = env
 
@@ -184,20 +184,20 @@ class CleverboxAdmin(cmd.Cmd):
 
         # root user & group
         # we keep the ssh_user notion for backward compatibility.
-        # this will have to disappear in a future release 
+        # this will have to disappear in a future release
         collected_infos['ssh_user'] = 0
         collected_infos['ssh_group'] = 0
 
         # Host server domain name
         collected_infos['domain'] = raw_input('Domain name > ').strip()
-        
+
         # Authentication backend password (if any)
         collected_infos['authbackend_pass'] = raw_input('Authentication backend password (if any) []> ').strip() or ''
 
         # Default configuration profile
         dcp = 'default'
         collected_infos['default_profile'] = raw_input('Default configuration profile [%s]> ' % dcp).strip() or dcp
-                
+
         # Write ini file
         self._config.add_section('general')
         for directive, value in collected_infos.items() :
@@ -213,7 +213,7 @@ class CleverboxAdmin(cmd.Cmd):
         self._config.add_section('trac')
         for directive, value in trac_infos.items() :
             self._config.set('trac', directive, str(value))
-        
+
         fh_config = open(os.path.join(self.envname, 'cleverbox.ini'), 'w+')
         self._config.write(fh_config)
 
@@ -240,7 +240,7 @@ class CleverboxAdmin(cmd.Cmd):
         print "\n\tCreating default configuration profile\n"
         for filename in _defaults['profile_files']:
             shutil.copy(collected_infos['assets_dir'] + '/' + filename, os.path.join(self.envname, 'profiles', 'default'))
-        
+
 
         print
         print "Environment successfully initialized\n"
@@ -250,7 +250,7 @@ class CleverboxAdmin(cmd.Cmd):
     _help_upgrade = [('upgrade', 'Executes necessary operation to make environment up to date')]
     def do_upgrade(self, line=None):
         env_version = open(os.path.join(self.envname, 'VERSION')).read()
-        if parse_version(env_version) < parse_version(_version): 
+        if parse_version(env_version) < parse_version(_version):
             from cleverbox.upgrades import upgrades
             i = 1
             while i:
@@ -260,7 +260,7 @@ class CleverboxAdmin(cmd.Cmd):
                 except AttributeError, e:
                     break
                 i = i + 1
-            
+
 
     ## help
     def do_help(self, line=None):
@@ -431,7 +431,7 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
             os.chown( os.path.join(collected_infos['home_dir'], 'tmp'),
                      int(self.getConfig('ssh_user', 'general')), int(self.getConfig('apache_group', 'general')) )
             os.chmod( os.path.join(collected_infos['home_dir'], 'tmp'), 0775 )
- 
+
             print "  Fixed permissions in %s\n" % collected_infos['home_dir']
 
             #  Final steps
@@ -794,13 +794,13 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
 
                 # -- Revoke all permissions in trac
                 self._project_trac_revoke_all_perms( collected_infos )
-        
+
                 # -- Trac initial permissions
                 self._project_trac_setperms( collected_infos )
 
                 # -- Modifies Trac default conf
                 self._project_trac_defaultconf( collected_infos )
-                
+
                 # -- Fix perms
                 self._project_fix_perms( collected_infos )
 
@@ -869,7 +869,7 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
                                 infos['client'],
                                 'var/svn',
                                 infos['short_name'] )
-	
+
         cmd_data = { 'env_path'         : trac_env_path,
                      'title'            : '"%s - %s - Trac"' % (infos['client'], infos['short_name']),
                      'db_dsn'           : 'sqlite:db/trac.db',
@@ -877,8 +877,8 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
                      'templates_path'   : '%s/templates' % self.getConfig('assets_dir', 'trac'),
                      'trac_install_dir' : self.getConfig('lib_dir', 'trac')}
 
-        trac_cmd = '/usr/bin/trac-admin %(env_path)s initenv %(title)s %(db_dsn)s svn %(svn_path)s %(templates_path)s' % cmd_data
-	
+        trac_cmd = 'trac-admin %(env_path)s initenv %(title)s %(db_dsn)s svn %(svn_path)s %(templates_path)s' % cmd_data
+
         (stdin, stdout, stderr) = os.popen3( trac_cmd )
 
         err = stderr.read()
@@ -922,19 +922,19 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
 
     def _project_trac_revoke_all_perms(self, infos):
         import trac.env
-        
+
         trac_env_path = os.path.join( self.getConfig('clients_root', 'general'),
                                      infos['client'],
                                      'var/trac',
                                      infos['short_name'] )
-        
+
         # Revoke all permissions
         trac_env = trac.env.open_environment(trac_env_path)
         trac_db = trac_env.get_db_cnx()
         db_cursor = trac_db.cursor()
         db_cursor.execute('DELETE FROM permission')
         trac_db.commit()
-        
+
         print "  Revoked Trac default permissions\n"
 
     def _project_fix_perms(self, infos):
@@ -969,7 +969,7 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
 				       'var','trac',
 				       infos['short_name'],
 				       'conf','trac.ini' )
-        os.chmod( trac_ini_path, 0777 )	
+        os.chmod( trac_ini_path, 0777 )
 
         # Subversion repository
         svn_repos_path = os.path.join( self.getConfig('clients_root', 'general'),
@@ -995,11 +995,11 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
         """
         Overrides project's default trac.ini with values provided in configuration profile.
         """
-        
+
         # New defaults
         tracdefaults_config = ConfigParser.SafeConfigParser()
         tracdefaults_config.read(os.path.join(self.envname, 'profiles', infos['profile'], 'trac-defaults.ini'))
-        
+
         # Trac base config file
         project_config_path = os.path.join(self.getConfig('clients_root', 'general'), infos['client'], 'var', 'trac', infos['short_name'], 'conf', 'trac.ini')
         tracproject_config = ConfigParser.SafeConfigParser()
